<?php

namespace Test123\Test123\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Test123\Test123\Models\Medicine;

class MedicinePolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the medicine.
     *
     * @param User $user
     * @param Medicine $medicine
     *
     * @return bool
     */
    public function view(User $user, Medicine $medicine)
    {
        if ($user->canDo('test123.medicine.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $medicine->user_id;
    }

    /**
     * Determine if the given user can create a medicine.
     *
     * @param User $user
     * @param Medicine $medicine
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('test123.medicine.create');
    }

    /**
     * Determine if the given user can update the given medicine.
     *
     * @param User $user
     * @param Medicine $medicine
     *
     * @return bool
     */
    public function update(User $user, Medicine $medicine)
    {
        if ($user->canDo('test123.medicine.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $medicine->user_id;
    }

    /**
     * Determine if the given user can delete the given medicine.
     *
     * @param User $user
     * @param Medicine $medicine
     *
     * @return bool
     */
    public function delete(User $user, Medicine $medicine)
    {
        if ($user->canDo('test123.medicine.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $medicine->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
